OC.L10N.register(
    "settings",
    {
    "Private" : "非公開",
    "Only visible to people matched via phone number integration through Talk on mobile" : "モバイルのTalkで電話番号が一致した人にのみ表示されます",
    "Local" : "ローカル",
    "Only visible to people on this instance and guests" : "このインスタンスのユーザーとゲストにのみ表示されます",
    "Federated" : "連携",
    "Only synchronize to trusted servers" : "信頼できるサーバーのみと同期する",
    "Published" : "公開",
    "Synchronize to trusted servers and the global and public address book" : "信頼できるサーバーへ、グローバルおよびパブリックアドレスブックを同期",
    "Verify" : "検証",
    "Verifying …" : "検証中",
    "Unable to change password" : "パスワードを変更できません",
    "Very weak password" : "非常に弱いパスワード",
    "Weak password" : "弱いパスワード",
    "So-so password" : "まずまずのパスワード",
    "Good password" : "良好なパスワード",
    "Strong password" : "強いパスワード",
    "Groups" : "グループ",
    "Group list is empty" : "グループリストが空です",
    "Unable to retrieve the group list" : "グループリストを取得できません",
    "{actor} added you to group {group}" : "{actor} があなたを {group} グループに追加しました",
    "You added {user} to group {group}" : "{user}を {group} グループに追加しました",
    "{actor} added {user} to group {group}" : "{actor} が{user}を {group} グループに追加しました",
    "An administrator added you to group {group}" : "管理者があなたを {group} グループに追加しました",
    "An administrator added {user} to group {group}" : "管理者が{user}を {group} グループに追加しました",
    "{actor} removed you from group {group}" : "{actor} があなたを {group} グループから外しました",
    "You removed {user} from group {group}" : "{user}を {group} グループから外しました",
    "{actor} removed {user} from group {group}" : "{actor} が{user}を {group} グループから外しました",
    "An administrator removed you from group {group}" : "管理者があなたを {group} グループから外しました",
    "An administrator removed {user} from group {group}" : "管理者が{user}を {group} グループから外しました",
    "Your <strong>group memberships</strong> were modified" : "<strong>グループメンバーシップ</strong>が変更されたとき",
    "{actor} changed your password" : "{actor} がパスワードを変更",
    "You changed your password" : "パスワードを変更",
    "Your password was reset by an administrator" : "管理者がパスワードをリセットしました",
    "Your password was reset" : "パスワードをリセットしました",
    "{actor} changed your email address" : "{actor} がメールアドレスを変更しました",
    "You changed your email address" : "メールアドレスを変更しました",
    "Your email address was changed by an administrator" : "管理者がメールアドレスを変更しました",
    "You deleted app password \"{token}\"" : "アプリパスワード\"{token}\"を削除しました",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "アプリのパスワードを{token} から {newToken} に変更しました。",
    "You granted filesystem access to app password \"{token}\"" : "アプリのパスワード\"{token}\"へファイルシステムアクセス件を付与しました",
    "You revoked filesystem access from app password \"{token}\"" : "アプリのパスワード\"{token}\"へファイルシステムアクセス件を取り下げました",
    "Security" : "セキュリティ",
    "You successfully logged in using two-factor authentication (%1$s)" : "二要素認証を使用して正常にログインしました (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "二要素認証を使用したログイン試行に失敗しました (%1$s)",
    "Remote wipe was started on %1$s" : "%1$sでリモートワイプが開始されました",
    "Remote wipe has finished on %1$s" : "%1$sのリモートワイプが完了しました",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong> パスワード </strong> または<strong> メールアドレス</strong>が更新されたとき",
    "Apps" : "アプリ",
    "Could not remove app." : "アプリを削除できませんでした。",
    "Could not update app." : "アプリを更新できませんでした。",
    "Wrong password" : "パスワードが間違っています",
    "Unable to change personal password" : "個人パスワードを変更できません",
    "Saved" : "保存しました",
    "No user supplied" : "ユーザーが指定されていません",
    "Unable to change password. Password too long." : "パスワードを変更できません。パスワードが長すぎます。",
    "Authentication error" : "認証エラー",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "リカバリ用の管理者パスワードを入力してください。そうしないと、全ユーザーのデータが失われます。",
    "Wrong admin recovery password. Please check the password and try again." : "リカバリ用の管理者パスワードが間違っています。パスワードを確認して再度実行してください。",
    "Backend does not support password change, but the user's encryption key was updated." : "バックエンドはパスワードの変更をサポートしていませんが、ユーザーの暗号化キーは正常に更新されました。",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "アプリストアまたはクラウド連携共有から、アプリをインストールならびにアップデート",
    "Federated Cloud Sharing" : "統合されたクラウド共有",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "%1$sバージョン (%2$s) の古い cURL を使っています。OSを更新するか、この機能 %3$sが正しく動くアプリに更新してください。",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "https://nextcloud.comに対するHTTPSリクエスト中にエラーが発生したため、cURLのTLSバージョンが古くなっているかどうかを判断できませんでした。詳細については、Nextcloudログファイルを確認してください。",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcacheモジュールがロードされていません。パフォーマンスを向上させるには、OPcacheモジュールをPHPインストールにロードすることをお勧めします。",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcacheが無効になっています。より良いパフォーマンスを得るためには、<code>1opcache.enable=1</code>をPHPの設定で適用することをおすすめします。",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcacheがコードのコメントを削除するように設定されています。Nextcloudを正しく動作させるため、OPcacheが有効の場合は、<code>opcache.save_comments=1</code>を設定する必要があります。",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "NextcloudはOPcache APIを使用する事が許可されていません。OPcacheが有効の場合、Nextcloudコアまたはアプリのアップグレード時にエラーを回避するため、全てのNextcloudディレクトリーに対して、<code>opcache.restrict_api</code>を含めるか、API制限を無効にするため、この設定を未設定にする事を強く推奨します。",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "NextcloudはOPcache APIを使用する事が許可されていません。Nextcloudコアまたはアプリのアップグレード時にエラーを回避するため、全てのNextcloudディレクトリーに対して、<code>opcache.restrict_api</code>を含めるか、API制限を無効にするため、この設定を未設定にする事を強く推奨します。",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcacheキーの最大数を間もなく超過します。全てのスクリプトをキャッシュに保管できるようにするには、<code>opcache.max_accelerated_files</code>の値を<code>%s</code>より多い値でPHP設定に適用することを推奨します。",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcacheバッファーがまもなく一杯になります。全てのスクリプトをキャッシュに保管できるようにするには、<code>opcache.memory_consumption</code>の値を<code>%s</code>より多い値で、PHP設定に適用することを推奨します。",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcacheのインターン化文字列バッファーがまもなく一杯になります。全てのスクリプトをキャッシュに保管できるようにするには、<code>opcache.interned_strings_buffer</code>の値を<code>%s</code>より多い値で、PHP設定に適用することを推奨します。",
    "Administrator documentation" : "管理者ドキュメント",
    "User documentation" : "ユーザードキュメント",
    "Invalid SMTP password." : "SMTPパスワードが無効",
    "Email setting test" : "メール設定のテスト",
    "Well done, %s!" : "%sさん、成功です！",
    "If you received this email, the email configuration seems to be correct." : "このメールが見えているということは、メール設定がうまくいっているということです。",
    "Email could not be sent. Check your mail server log" : "メールが送信できませんでした。メールサーバーのログを確認してください",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "メールの送信中に問題が発生しました。設定を確認してください。 (Error: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "テストメールを送信する前に、ユーザーメールを設定する必要があります。%sから設定を行ってください。",
    "Users" : "ユーザー",
    "Invalid user" : "無効なユーザー",
    "Invalid mail address" : "無効なメールアドレスです",
    "Settings saved" : "設定を保存しました",
    "Unable to change full name" : "名前を変更できません",
    "Unable to change email address" : "メールアドレスを変更できません",
    "Unable to set invalid phone number" : "無効な携帯番号を設定できません",
    "Unable to set invalid website" : "Webサイトが無効で設定できません",
    "Some account data was invalid" : "一部のアカウントデータは無効です",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "あなたのTwitterアカウントを確認するには、以下のツイートをTwitterに投稿してください（改行なしで投稿してください）：",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "あなたのウェブサイトを確認するため、次の内容をウェブルートの'.well-known/CloudIdVerificationCode.txt'に保存します。（完全な文章で一文になっていることを確かめてください。）",
    "%1$s changed your password on %2$s." : "%1$sが %2$sでパスワードを変更しました。",
    "Your password on %s was changed." : "%s のパスワードを変更しました。",
    "Your password on %s was reset by an administrator." : "%sのパスワードは、管理者がリセットしました。",
    "Your password on %s was reset." : "%s のパスワードをリセットしました。",
    "Password for %1$s changed on %2$s" : "%2$sで %1$sのパスワードが変更されました",
    "Password changed for %s" : "%s のパスワードが変更されました",
    "If you did not request this, please contact an administrator." : "この操作に覚えがない場合は、管理者に問い合わせてください。",
    "Your email address on %s was changed." : "%s のメールアドレスを変更しました。",
    "Your email address on %s was changed by an administrator." : "%s のメールアドレスを管理者が変更しました。",
    "Email address for %1$s changed on %2$s" : "%1$s のメールアドレスが %2$sで変更しました。",
    "Email address changed for %s" : "%s のメールアドレスを変更しました",
    "The new email address is %s" : "新しいメールアドレスは、%s です",
    "Your %s account was created" : "%s アカウントを作成しました",
    "Welcome aboard" : "ようこそ",
    "Welcome aboard %s" : "%s さん、ようこそ",
    "Welcome to your %s account, you can add, protect, and share your data." : "%s アカウントにようこそ。あなたのデータを追加、保護、共有することができます。",
    "Your username is: %s" : "あなたの名前: %s",
    "Set your password" : "パスワードを設定",
    "Go to %s" : "%s に移動",
    "Install Client" : "クライアントをインストール",
    "Logged in user must be a subadmin" : "ログインユーザーはサブ管理者である必要があります",
    "Settings" : "設定",
    "Personal" : "個人",
    "Administration" : "管理",
    "Additional settings" : "追加設定",
    "Administration privileges" : "管理者権限",
    "Groupware" : "グループウェア",
    "Overview" : "概要",
    "Basic settings" : "基本設定",
    "Sharing" : "共有",
    "Availability" : "応対可能日時",
    "Calendar" : "カレンダー",
    "Personal info" : "個人情報",
    "Mobile & desktop" : "モバイル & デスクトップ",
    "Email server" : "メールサーバー",
    "Security & setup warnings" : "セキュリティ＆セットアップ警告",
    "Background jobs" : "バックグラウンドジョブ",
    "Create" : "作成",
    "Change" : "変更",
    "Delete" : "削除",
    "Reshare" : "再共有",
    "Unlimited" : "無制限",
    "Verifying" : "検証中",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "ユーザーがインポートしたSSL証明書をチェックするバックグラウンドジョブが保留になっています。しばらくして再度確認してください。",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "ユーザーがインポートしたSSL証明書がいくつか存在しますが、Nextcloud 21ではもう使用されていません。これらの証明書は、\"occ security:certificates:import\" コマンドにより、コマンドラインでインポートすることができます。これらの証明書のデータディレクトリ内のパスは以下のとおりです。",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "無効なLDAPユーザーまたはグループのUUIDが見つかりました。LDAP設定の詳細設定に存在する\"UUID検出の上書き\"設定を再度ご確認いただき、更新するには\"occ ldap:update-uuid\"をご使用ください。",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "古い方式のサーバーサイド暗号化が有効になっています。無効にすることをお勧めします。",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB のバージョン\"%s\" が使われています。Nextcloud 21以降ではこのバージョンのサポートは終了し、MariaDB 10.2 以降のバージョンが必要になります。",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQLのバージョン \"%s\" が使用されています。Nextcloud 21以降ではこのバージョンのサポートは終了し、MySQL 8.0またはMariaDB 10.2以上が必要となります。",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQLのバージョン \"%s\" を使用しています。Nextcloud 21以降ではこのバージョンのサポートは終了し、PostgreSQL 9.6以降が必要となります。",
    "Profile information" : "プロフィール情報",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "プロフィール写真、氏名、メールアドレス、電話番号、住所、Webサイト、Twitter、組織、役職、ヘッドライン、自己紹介が有効かどうか",
    "Nextcloud settings" : "Nextcloud の設定",
    "Here you can decide which group can access certain sections of the administration settings." : "ここではどのグループが、どの管理設定項目にアクセスできるか決めることができます。",
    "None" : "なし",
    "Unable to modify setting" : "設定を変更できません",
    "Two-Factor Authentication" : "二要素認証",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "二要素認証はすべてのユーザーと特定のグループに強制することができます。設定済みの二要素プロバイダーがない場合は、システムにログインできません。",
    "Enforce two-factor authentication" : "二要素認証を強制する",
    "Limit to groups" : "次のグループに制限",
    "Enforcement of two-factor authentication can be set for certain groups only." : "二要素認証の強制は特定のグループのみに設定できます。",
    "Two-factor authentication is enforced for all members of the following groups." : "二要素認証は次のグループのすべてのメンバーに強制されています。",
    "Enforced groups" : "強制するグループ",
    "Two-factor authentication is not enforced for members of the following groups." : "次のグループのメンバーの場合、二要素認証は強制されません。",
    "Excluded groups" : "除外するグループ",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "グループが選択または除外されている場合、ユーザーに対して二要素認証を強制するかを次のロジックで判断します: 強制するグループが未選択の場合、除外するグループのメンバーを除く全ユーザーに対して二要素認証を強制します。強制するグループが選択されている場合、強制するグループの全メンバーに対して二要素認証を強制します。両方のグループに所属するユーザーに対しては、強制するグループが優先され、二要素認証が強制されます。",
    "Save changes" : "変更を保存",
    "All" : "すべて",
    "Limit app usage to groups" : "アプリの使用をグループに制限する",
    "No results" : "該当なし",
    "Update to {version}" : "{version} にアップデート",
    "Remove" : "削除",
    "Disable" : "無効にする",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "このアプリは Nextcloud の最小バージョンが指定されていません．将来、エラーが発生する可能性があります.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "このアプリは Nextcloud バージョンの上限が指定されていません．将来、エラーが発生する可能性があります.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "次の依存関係が満たされないためこのアプリをインストールできません:",
    "View in store" : "ストア内で表示",
    "Visit website" : "ウェブサイトを表示",
    "Report a bug" : "不具合を報告",
    "Admin documentation" : "管理者ドキュメント",
    "Developer documentation" : "開発者ドキュメント",
    "This app is supported via your current Nextcloud subscription." : "このアプリは、現行のNextcloudサブスクリプションでサポートされています。",
    "Supported" : "対応しています",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "注目のアプリはコミュニティ内で開発されています。これらのアプリは主要な機能を提供しており、すぐに本番で使用することができます。",
    "Featured" : "注目",
    "Update to {update}" : "{update} にアップデート",
    "All apps are up-to-date." : "全てのアプリが最新です",
    "Results from other categories" : "他のカテゴリからの結果",
    "No apps found for your version" : "現在のバージョンに対応するアプリはありません",
    "Disable all" : "すべて無効にする",
    "Enable all" : "すべて有効にする",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n 個のアプリに更新情報があります"],
    "_Update_::_Update all_" : ["全て更新"],
    "Marked for remote wipe" : "リモートワイプ用にマーク",
    "Device settings" : "デバイスの設定",
    "Allow filesystem access" : "ファイルシステムへのアクセスを許可",
    "Rename" : "名前を変更",
    "Revoke" : "取り消す",
    "Wipe device" : "デバイスをワイプ",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "ワイプが開始されていない場合、このトークンを無効にすると端末のワイプが無効になる可能性があります。",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Android用Google Chrome",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOSアプリ",
    "{productName} Android app" : "{productName} Androidアプリ",
    "{productName} Talk for iOS" : "{productName} iOS用Talk",
    "{productName} Talk for Android" : "{productName} Android用Talk",
    "Sync client - {os}" : "同期用クライアント - {os}",
    "This session" : "本セッション",
    "Device" : "デバイス",
    "Last activity" : "最後のアクティビティ",
    "Devices & sessions" : "デバイスとセッション",
    "Web, desktop and mobile clients currently logged in to your account." : "現在、Web、デスクトップ、モバイルアプリであなたのアカウントにログインしている端末一覧です。",
    "Do you really want to wipe your data from this device?" : "本当にこの端末からデータを消去しますか？",
    "Confirm wipe" : "ワイプ確認",
    "Error while creating device token" : "デバイストークンの作成中にエラーが発生しました",
    "Error while updating device token scope" : "デバイストークンのスコープ更新中にエラーが発生しました",
    "Error while updating device token name" : "デバイストークン名の更新中にエラーが発生しました",
    "Error while deleting the token" : "トークンの削除中にエラーが発生しました",
    "Error while wiping the device with the token" : "トークンによる端末のワイプ中にエラーが発生しました",
    "App name" : "アプリ名",
    "Create new app password" : "新しいアプリパスワードを作成",
    "Use the credentials below to configure your app or device." : "アプリや端末を設定するのに以下の認証情報を使用する。",
    "For security reasons this password will only be shown once." : "セキュリティ上の理由から、このパスワードは一度しか表示されません。",
    "Username" : "ユーザーID",
    "Password" : "パスワード",
    "Done" : "完了",
    "Show QR code for mobile apps" : "モバイルアプリのQRコードを表示する",
    "Copied!" : "コピーしました！",
    "Copy" : "コピー",
    "Could not copy app password. Please copy it manually." : "アプリのパスワードをコピーできませんでした。 手動でコピーしてください。",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "サーバーが正しく動作するには、バックグラウンドジョブを正確に設定することが重要です。大規模なインスタンスでは、Cronがお薦めの設定です。詳細な情報は、ドキュメントを参照してください。",
    "Last job execution ran {time}. Something seems wrong." : "最終ジョブ実行は %s です。何か問題が発生しています。",
    "Last job ran {relativeTime}." : "最終ジョブ実行は {relativeTime} です。",
    "Background job did not run yet!" : "バックグラウンドジョブはまだ実行されていません！",
    "AJAX" : "Ajax",
    "Execute one task with each page loaded. Use case: Single user instance." : "各ページが読み込まれる度に1つのタスクを実行します。使用例: シングルユーザーのインスタンスの場合。",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.phpは、HTTP越しに5分おきにcron.phpを読み出すWebcronサービスにより登録されています。使用例: 極小なインスタンス(利用率に依存する1〜5ユーザー程度)の場合。",
    "Cron (Recommended)" : "Cron (推奨)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "これを実行するにはPHPのposix拡張が必要です。詳細については、{linkstart} PHPドキュメント{linkend}を参照してください。",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "システムのcronサービスを利用して、5分ごとにcron.phpファイルを実行します。全てのインスタンスで推奨されます。",
    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php はシステムユーザー \"{user}\" で実行する必要があります。",
    "Unable to update background job mode" : "バックグラウンドジョブモードが更新できませんでした",
    "Profile" : "プロフィール",
    "Enable or disable profile by default for new users." : "新規ユーザーのプロフィールの有効・無効(デフォルト)",
    "Enable" : "有効にする",
    "Unable to update profile default setting" : "プロフィールのデフォルト設定を更新できませんでした",
    "Server-side encryption" : "サーバーサイド暗号化",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "サーバーサイド暗号化では、このサーバーにアップロードされるファイルを暗号化することができます。この設定を行うとパフォーマンス劣化のような制限を伴いますので、必要な場合のみ有効にしてください。",
    "Enable server-side encryption" : "サーバーサイド暗号化を有効にする",
    "Please read carefully before activating server-side encryption:" : "サーバー側の暗号化を適用にする前に、よくお読みください:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "いったん暗号化を有効にすると、この時点からサーバーにアップロードされるすべてのファイルが暗号化されサーバー上に入ります。有効化された暗号モジュールは復号化機能をサポートしますが、すべての前提条件が満たされている(例えば、回復キーが設定されている)場合にのみ、後日暗号化を無効にできます。",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "暗号化だけで、システムのセキュリティが保証されるわけではありません。暗号化アプリがどのように動作するかの詳細な情報や、サポートされているユースケースについては、Nextcloud のドキュメントを参照してください。",
    "Be aware that encryption always increases the file size." : "暗号化は、常にファイルサイズが増加することに注意してください。",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "暗号化した場合には必ず、あなたのデータと共に暗号化キーをバックアップすることを確認し、定期的にデータをバックアップを作成することをお勧めします。",
    "This is the final warning: Do you really want to enable encryption?" : "これが最後の警告です：本当に暗号化を有効にしますか？",
    "No encryption module loaded, please enable an encryption module in the app menu." : "暗号化モジュールがロードされていません。アプリのメニューから暗号化モジュールを有効化してください。",
    "Select default encryption module:" : "デフォルトの暗号化モジュールを選択:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "暗号化キーを古い暗号化 (ownCloud <= 8.0) から新しい暗号化に移行する必要があります。 \"デフォルトの暗号化モジュール\" を有効にして {command} を実行してください",
    "Unable to update server side encryption config" : "サーバー側暗号化の設定を更新できませんでした",
    "Rename group" : "グループの名称変更",
    "Remove group" : "グループを削除",
    "You are about to remove the group {group}. The users will NOT be deleted." : "{group}グループを削除しようとしています。 ユーザーは削除されません。",
    "Please confirm the group removal " : "グループの削除を確認してください",
    "Current password" : "現在のパスワード",
    "New password" : "新しいパスワード",
    "Change password" : "パスワードを変更",
    "Your profile picture" : "プロフィール画像",
    "Upload profile picture" : "新しいプロフィール画像のアップロード",
    "Remove profile picture" : "プロフィール画像を削除",
    "Picture provided by original account" : "オリジナルのアカウントで提供されている写真",
    "Cancel" : "キャンセル",
    "Set as profile picture" : "プロフィール画像として設定",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "プロフィール写真がすべての場所で更新されるまで、最大 24 時間かかる場合があることに注意してください。",
    "Choose your profile picture" : "プロフィール画像を選択",
    "Please select a valid png or jpg file" : "pngもしくは、jpgファイルを選択してください",
    "Error setting profile picture" : "プロフィール画像に設定できませんでした",
    "Error cropping profile picture" : "プロフィール画像を切り取れませんでした",
    "Error saving profile picture" : "プロフィール画像を保存できませんでした",
    "Error removing profile picture" : "プロフィール画像を削除できませんでした",
    "Your biography" : "あなたのプロファイル",
    "Details" : "詳細",
    "You are a member of the following groups:" : "次のグループに所属:",
    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong>使用中です",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "<strong>{totalSpace}</strong> (<strong>{usageRelative}</strong>) のうち<strong>{usage}</strong>を使用しています",
    "Your full name" : "フルネーム",
    "Email options" : "メールのオプション",
    "Primary email for password reset and notifications" : "パスワードのリセットや通知のための基本メールアドレス",
    "Remove primary email" : "基本メールアドレスを削除",
    "Delete email" : "メールアドレスを削除",
    "Unset as primary email" : "基本メールアドレスを解除",
    "This address is not confirmed" : "このアドレスは確認できていません",
    "Set as primary email" : "基本メールアドレスに設定",
    "Your email address" : "あなたのメールアドレス",
    "Additional email address {index}" : "その他のメールアドレス {index}",
    "Unable to delete primary email address" : "基本メールアドレスを削除できませんでした",
    "Unable to update primary email address" : "基本メールアドレスを更新できませんでした",
    "Unable to add additional email address" : "その他のメールアドレスを追加できません",
    "Unable to update additional email address" : "その他のメールアドレスを更新できません",
    "Unable to delete additional email address" : "その他のメールアドレスを削除できません",
    "No email address set" : "メールアドレスが設定されていません",
    "Additional emails" : "その他のメールアドレス",
    "Your headline" : "あなたのヘッドライン",
    "Language" : "言語",
    "Help translate" : "翻訳に協力する",
    "Unable to update language" : "言語設定を更新できませんでした",
    "No language set" : "言語設定なし",
    "Locale" : "ロケール",
    "Week starts on {firstDayOfWeek}" : "週の始まりは{firstDayOfWeek}です。",
    "Unable to update locale" : "ロケールを更新できませんでした",
    "No locale set" : "ロケールは未設定",
    "Your location" : "位置情報",
    "Your organisation" : "あなたの組織",
    "Your phone number" : "あなたの電話番号",
    "Edit your Profile visibility" : "プロフィールの公開範囲を変更",
    "Enable Profile" : "プロフィールを有効化",
    "Unable to update profile enabled state" : "プロフィールを公開できません",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "プロフィール公開ページは、可視性またはスコープのより制限的な設定が優先されます。たとえば、可視性が「全員に表示」に設定され、スコープが「プライベート」に設定されている場合、「プライベート」が尊重されます。",
    "Unable to update visibility of {displayId}" : "{displayId}の表示範囲を更新できませんでした",
    "Your role" : "あなたの役",
    "Your Twitter handle" : "あなたのTwitterのID",
    "Your website" : "あなたの個人ウェブサイト",
    "No {property} set" : "{property} は未設定",
    "Unable to update {property}" : "{property}を更新できませんでした",
    "Change scope level of {property}, current scope is {scope}" : "{property}の公開範囲を変更、現在の公開範囲は{scope}です",
    "Unable to update federation scope of the primary {property}" : "プライマリー{property}のフェデレーションスコープを更新できませんでした",
    "Unable to update federation scope of additional {property}" : "追加の{property}のフェデレーションスコープを更新できませんでした",
    "Add additional email" : "その他メールアドレスを追加",
    "Add" : "追加",
    "You do not have permissions to see the details of this user" : "このユーザーの詳細を表示する権限がありません",
    "Add new password" : "新しいパスワードを追加する",
    "Add new email address" : "新しいメールアドレスを追加する",
    "Add user to group" : "ユーザーをグループに追加",
    "Set user as admin for" : "ユーザーを管理者に設定します",
    "Select user quota" : "ユーザークオータを選択",
    "Delete user" : "ユーザーを削除",
    "Wipe all devices" : "すべての端末をワイプ",
    "Disable user" : "ユーザーを無効",
    "Enable user" : "ユーザーを有効",
    "Resend welcome email" : "ウェルカムメールを再送する",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "デバイスを紛失した場合や、組織外に出た場合、{userid}に関連付けられたすべてのデバイスからリモートで Nextcloud のデータを消去することができます。デバイスがインターネットに接続されている場合にのみ機能します。",
    "Remote wipe of devices" : "デバイスのリモートワイプ",
    "Wipe {userid}'s devices" : " {userid} のデバイスをワイプ",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "{userid} の個人ファイルやアプリケーションデータなどを含むアカウントを完全に削除します。",
    "Account deletion" : "アカウント削除",
    "Delete {userid}'s account" : "{userid} のアカウントを削除する",
    "Welcome mail sent!" : "ウェルカムメールを送信しました！",
    "Edit User" : "ユーザーを編集する",
    "Toggle user actions menu" : "ユーザーアクションメニューを切り替える",
    "{size} used" : "{size} を使用中",
    "New user" : "新しいユーザー",
    "Will be autogenerated" : "自動生成されます",
    "Display name" : "表示名",
    "Email" : "メール",
    "Default language" : "デフォルトの言語",
    "Add a new user" : "新しいユーザーを追加",
    "Group admin for" : "グループの管理者",
    "Quota" : "クオータ",
    "User backend" : "ユーザーバックエンド",
    "Storage location" : "データの保存場所",
    "Last login" : "最終ログイン",
    "No users in here" : "ここにはユーザーがありません",
    "Default quota" : "デフォルトのクオータ",
    "Common languages" : "共通言語",
    "Other languages" : "他の言語",
    "Password change is disabled because the master key is disabled" : "マスターキーが無効になっているため、パスワードの変更は無効です",
    "Passwordless authentication requires a secure connection." : "パスワードレス認証では、安全な接続が必要です。",
    "Add WebAuthn device" : "WebAuthn デバイスの追加",
    "Please authorize your WebAuthn device." : "WebAuthn デバイスを認証してください。",
    "Name your device" : "デバイスに名前をつける",
    "Adding your device …" : "あなたのデバイスを追加しています…",
    "Server error while trying to add WebAuthn device" : "WebAuthn デバイスを追加しようとしたときのサーバーエラー",
    "Server error while trying to complete WebAuthn device registration" : "WebAuthn デバイス登録を完了しようとしたときのサーバーエラー",
    "Unnamed device" : "名称設定されていないデバイス",
    "Passwordless Authentication" : "パスワードレス認証",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "FIDO2 規格に準拠したパスワードレス認証のためのアカウントを設定します。",
    "No devices configured." : "設定されたデバイスはありません。",
    "The following devices are configured for your account:" : "アカウントには以下のデバイスが設定されています。",
    "Your browser does not support WebAuthn." : "お使いのブラウザーは WebAuthn をサポートしていません。",
    "Your apps" : "あなたのアプリ",
    "{license}-licensed" : "{license}-に許諾されています",
    "Changelog" : "変更履歴",
    "by {author}\n{license}" : "作者 {author}\n{license}",
    "Enter group name" : "グループ名を入力",
    "Add group" : "グループを追加する",
    "Active users" : "アクティブユーザー数",
    "Admins" : "管理者",
    "Disabled users" : "無効なユーザー",
    "Default quota:" : "デフォルトのクオータ:",
    "Select default quota" : "デフォルトのクオータを選択",
    "Show Languages" : "言語を表示",
    "Show last login" : "最終ログインを表示",
    "Show user backend" : "ユーザーバックエンドを表示",
    "Show storage path" : "ストレージの場所を表示",
    "Send email to new user" : "新規ユーザーにメールを送信",
    "Not saved" : "未保存",
    "Sending…" : "送信中 …",
    "Email sent" : "メールを送信しました",
    "Location" : "位置",
    "Profile picture" : "プロフィール画像",
    "About" : "説明",
    "Full name" : "氏名",
    "Additional email" : "その他のメールアドレス",
    "Headline" : "ヘッドライン",
    "Organisation" : "組織",
    "Phone number" : "電話番号",
    "Role" : "役職",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "フェディバース (例: Mastdon)",
    "Website" : "ウェブサイト",
    "Profile visibility" : "プロフィールの公開範囲",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "このプロパティは、ファイル共有やカレンダーへの招待などのコア機能に必要なため、使用できません",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "お客様のアカウントでフェデレーションが無効になっているため利用できません。不明な点がある場合は、システム管理者にお問い合わせください",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "ユーザー固有のデータをルックアップサーバーに公開することは許可されていないため、利用できません。ご不明な点がある場合は、システム管理者にお問い合わせください",
    "Active apps" : "アクティブなアプリ",
    "Disabled apps" : "無効なアプリ",
    "Updates" : "アップデート",
    "App bundles" : "アプリバンドル",
    "Featured apps" : "注目のアプリ",
    "Show to everyone" : "全員に見せる",
    "Show to logged in users only" : "ログインしているユーザーだけに見せる",
    "Hide" : "隠す",
    "Download and enable" : "ダウンロードして有効にする",
    "Enable untested app" : "未テストのアプリを有効にする",
    "The app will be downloaded from the App Store" : "このアプリは、アプリストアからダウンロードできます。",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "このアプリはご利用中のNextcloudのバージョンと互換性があるとしてマークされていません。 続行しても、アプリをインストールすることはできます。 アプリが期待通りに動作しない可能性があることに注意してください。",
    "Never" : "なし",
    "An error occurred during the request. Unable to proceed." : "要求中にエラーが発生しました。 続行できません。",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "アプリは有効ですが、更新が必要です。5秒後に更新ページにリダイレクトします。",
    "Error: This app cannot be enabled because it makes the server unstable" : "エラー：このアプリは、サーバーを不安定にするため、有効にすることができません。",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ネットワークからのリクエストが多すぎました。このようなエラーが発生した場合は、後で再試行するか、管理者に連絡してください。",
    "Documentation" : "ドキュメント",
    "Forum" : "フォーラム",
    "Login" : "ログイン",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "ドキュメントを開く",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "パスワードのリセットや通知などのメールを送信できるよう、このサーバーを設定することが重要です。",
    "Send mode" : "送信モード",
    "Encryption" : "暗号化",
    "Sendmail mode" : "Sendmailモード",
    "From address" : "送信元アドレス",
    "Server address" : "サーバーアドレス",
    "Port" : "ポート",
    "Authentication method" : "認証方法",
    "Authentication required" : "認証を必要とする",
    "Credentials" : "資格情報",
    "SMTP Username" : "SMTPユーザー名",
    "SMTP Password" : "SMTPパスワード",
    "Save" : "保存",
    "Test and verify email settings" : "メールのテストと検証設定",
    "Send email" : "メールを送信",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "サーバーのセキュリティとパフォーマンスにとって重要なことは、すべてが正確に設定されていることです。あなたの助けとなるよう、Nextcloudでは一部の自動チェックを行っています。詳細な情報は、リンク先のドキュメントを参照してください。",
    "All checks passed." : "すべてのチェックに合格しました。",
    "There are some errors regarding your setup." : "セットアップに関するいくつかのエラーがあります。",
    "There are some warnings regarding your setup." : "セットアップに関して警告がいくつかあります。",
    "Checking for system and security issues." : "システムおよびセキュリティの問題をチェックしています。",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">インストールガイド ↗</a>を再確認して、 <a href=\"%2$s\">ログ</a> にあるすべてのエラーや警告を確認してください。",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Nextcloudのセキュリティは、<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">セキュリティスキャン ↗</a>でチェックしてください。",
    "Version" : "バージョン",
    "You need to enable the File sharing App." : "ファイル共有アプリを有効にする必要があります。",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "管理者であれば共有時の挙動を微調整できます。詳細な情報はドキュメントを参照してください。",
    "Allow apps to use the Share API" : "アプリからの共有APIの利用を許可する",
    "Set default expiration date for shares" : "共有のデフォルトの有効期限を設定する",
    "Expire after" : "有効期限",
    "day(s)" : "日",
    "Enforce expiration date" : "有効期限を反映させる",
    "Set default expiration date for shares to other servers" : "他のサーバーへの共有のデフォルトの有効期限を設定する",
    "Allow users to share via link and emails" : "URLリンクとメールでの共有を許可する",
    "Allow public uploads" : "パブリックなアップロードを許可する",
    "Always ask for a password" : "常にパスワードをたずねる",
    "Enforce password protection" : "常にパスワード保護を有効にする",
    "Exclude groups from password requirements:" : "パスワード要件から除外するグループ:",
    "Set default expiration date" : "有効期限のデフォルト値を設定する",
    "Exclude groups from creating link shares:" : "リンク共有作成を除外するグループ: ",
    "Allow resharing" : "再共有を許可する",
    "Allow sharing with groups" : "グループ共有を許可する",
    "Restrict users to only share with users in their groups" : "グループ内のユーザーでのみ共有するように制限する",
    "Exclude groups from sharing" : "共有可能なグループから除外する",
    "These groups will still be able to receive shares, but not to initiate them." : "このグループでは、フォルダー共有を開始することはできませんが、共有されたフォルダーを参照することはできます。",
    "Allow username autocompletion in share dialog" : "共有ダイアログでユーザー名を自動補完する",
    "Allow username autocompletion to users within the same groups" : "同じグループ内のユーザーのみユーザー名を自動補完する",
    "Allow username autocompletion to users based on phone number integration" : "電話番号を連携しているユーザーのユーザー名を自動補完する",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "自動補完で「同じグループ」と「電話番号の連携」が有効になっている場合は、どちらかに一致するだけでユーザーに表示されます。",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "氏名または電子メールアドレスを入力するときにユーザー名を自動補完する（連絡先での不一致、同じグループへの所属かどうかを無視）",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "公開リンクのアップロードページに免責事項のテキストを表示する。 (ファイルリストが非表示のときのみ表示します)",
    "This text will be shown on the public link upload page when the file list is hidden." : "このテキストは、ファイルリストが非表示になっているときに公開リンクのアップロードページに表示されます。",
    "Default share permissions" : "デフォルトの共有アクセス許可",
    "Reasons to use Nextcloud in your organization" : "あなたの組織でNextcloudを使うべきこれだけの理由",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen} Nextcloudコミュニティ{linkclose}によって開発された{githubopen}ソースコード{linkclose}は、{licenseopen} AGPL {linkclose}で許諾されています。",
    "Like our Facebook page" : "私たちのFacebookのページをイイネ！",
    "Follow us on Twitter" : "Twitter でフォロー！",
    "Follow us on Mastodon" : "Mastodonでフォロー",
    "Check out our blog" : "私たちのブログを見てね！",
    "Subscribe to our newsletter" : "ニュースレターを購読する！",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "このコミュニティリリースのNextcloudは未サポートです。インスタント通知も利用できません。",
    "Use a second factor besides your password to increase security for your account." : "アカウントのセキュリティを強化するには、パスワード以外に2番目の要素を使用してください。",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "サードパーティのアプリケーションを使用してNextcloudに接続する場合は、二要素認証を有効にする前に必ずそれぞれのアプリパスワードを作成して設定してください。",
    "An error occurred while changing your language. Please reload the page and try again." : "言語を変更する際にエラーが発生しました。ページをリロードして、再度試してください。",
    "An error occurred while changing your locale. Please reload the page and try again." : "ロケールの変更中にエラーが発生しました。 ページをリロードしてもう一度お試しください。",
    "Select a profile picture" : "プロフィール画像を選択",
    "Week starts on {fdow}" : "週は{fdow}から始まります",
    "You created app password \"{token}\"" : "アプリパスワード\"{token}\"を作成しました",
    "An administrator created app password \"{token}\"" : "管理者がアプリパスワード\"{token}\"を作成しました",
    "Couldn't remove app." : "アプリが削除できませんでした。",
    "Couldn't update app." : "アプリをアップデートできませんでした。",
    "Backend doesn't support password change, but the user's encryption key was updated." : "バックエンドはパスワードの変更をサポートしていませんが、ユーザーの暗号化キーは正常に更新されました。",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "https://nextcloud.comに対するHTTPSリクエスト中にエラーが発生したため、cURLのTLSバージョンが古くなっているかどうかを判断できませんでした。詳細については、nextcloudログファイルを確認してください。",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcacheキーの最大数を間もなく超過します。全てのスクリプトをキャッシュに保管できるようにするには、<code>opcache.max_accelerated_files</code>の値を<code>%s</code>より多い値でPHP設定に適用することを推奨します。",
    "Admin privileges" : "管理者権限",
    "Unable to update biography" : "プロファイルを更新できません",
    "Unable to update full name" : "フルネームを更新できません",
    "No full name set" : "フルネームが未設定です",
    "Unable to update headline" : "ヘッドラインを更新できませんでした",
    "Unable to update organisation" : "組織を更新できませんでした",
    "Unable to update role" : "役職の更新ができませんでした",
    "Change scope level of {accountProperty}" : "{accountProperty}のスコープレベルを変更",
    "Unable to update federation scope of the primary {accountProperty}" : "プライマリー{accountProperty}のフェデレーションスコープを更新できませんでした",
    "Unable to update federation scope of additional {accountProperty}" : "追加の{accountProperty}のフェデレーションスコープを更新できませんでした",
    "Migration in progress. Please wait until the migration is finished" : "移行の処理中です。移行が完了するまでお待ちください。",
    "Migration started …" : "移行を開始しました…",
    "Address" : "住所",
    "Avatar" : "アバター",
    "An error occured during the request. Unable to proceed." : "要求中にエラーが発生しました。 続行できません。",
    "Plain" : "平文",
    "NT LAN Manager" : "NT LAN マネージャー",
    "STARTTLS" : "STARTTLS",
    "Please read carefully before activating server-side encryption: " : "サーバーサイド暗号化を有効にする前によく読んでください:",
    "Enable encryption" : "暗号化を有効にする",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "古い暗号化(ownCloud <= 8.0) から新しいものに暗号化キーを移行する必要があります。\"デフォルトの暗号化モジュール\" を有効にして 'occ encryption:migrate' を実行してください。",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "古い暗号化(ownCloud <= 8.0) から新しいものに暗号化キーを移行する必要があります。",
    "Start migration" : "移行を開始",
    "Last job execution ran %s. Something seems wrong." : "最終ジョブ実行は %s です。何か問題が発生しています。",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "%s 以降に実行されていないジョブがあります。実行頻度を上げることを検討してください。",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "%s 以降、一部のジョブが実行されませんでした。cron への切り替えを検討してください。",
    "Last job ran %s." : "最終ジョブ実行: %s",
    "Background job didn’t run yet!" : "バックグラウンドジョブは実行されていません",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "サーバーが正しく動作するには、バックグラウンドジョブを正確に設定することが重要です。大規模なインスタンスでは、\"Cron\"がお薦めの設定です。詳細な情報は、ドキュメントを参照してください。",
    "Pick background job setting" : "バックグラウンドジョブ設定を選択",
    "Recommended" : "おすすめ",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php はシステムユーザー \"%s\" で実行する必要があります。",
    "Change privacy level of profile picture" : "プロフィール写真のプライバシーレベルを変更",
    "Upload new" : "新たにアップロード",
    "Select from Files" : "ファイルから選択",
    "Remove image" : "画像を削除",
    "png or jpg, max. 20 MB" : "pngまたはjpg。最大20MB",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "全ての場所でアバターが更新されるまでに最大二四時間かかる場合があります。",
    "Choose as profile picture" : "プロフィール画像として選択",
    "You are using <strong>%s</strong>" : "<strong>%s</strong>を現在使用中です",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "<strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>) 使用中",
    "Change privacy level of phone number" : "電話番号のプライバシーレベルを変更",
    "Change privacy level of address" : "住所のプライバシーレベルを変更",
    "Your postal address" : "あなたの住所",
    "Change privacy level of website" : "Webサイトのプライバシーレベルを変更",
    "It can take up to 24 hours before the account is displayed as verified." : "アカウントが確認済みとして表示されるまでには最大24時間かかることがあります。",
    "Link https://…" : "リンク https://...",
    "Change privacy level of Twitter profile" : "Twitterプロフィールのプライバシーレベルを変更",
    "Twitter handle @…" : "あなたのTwitter ID @...",
    "Choose profile picture from files" : "ファイルからプロフィール画像を選択"
},
"nplurals=1; plural=0;");
